@@ -16,10 +16,7 @@ template <typename Element>
 class
     Community :
     public core::SortedRandomSet<Element>
-{
-public:
-    virtual ~Community() = default;
-};
+{};
 
 }
 }
